starcluster.node.NodeManager

Package starcluster :: Module node :: Class NodeManager |
[hide private]
[frames] | no frames]

# Class NodeManager

source code

Manager class for Node objects

Instance Methods | [hide private]
ssh_to_node(self, node_id, user=`'``root``'`) | source code
get_node(self, node_id, user=`'``root``'`) Factory for Node class | source code
Inherited from `managers.Manager`: `__init__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`